(() => {
  'use strict';

  // -------------------------------------
  // 共通関数
  // -------------------------------------
  // 小計取得
  const getRowTotal = (unitPrice, quantity) => unitPrice * quantity;

  // 合計金額取得
  const getTotal = details => details.reduce((p, c) => p + Number(c.value.小計.value), 0);

  // 総合計金額取得
  const getAllTotal = (total, adjust) => total + adjust;

  // -------------------------------------
  // 追加画面と編集画面のフィールド値変更イベント
  // -------------------------------------
  kintone.events.on([
    'app.record.create.change.明細',
    'app.record.edit.change.明細'
  ], event => {
    const record = event.record;

    console.log('change.明細');

    record.合計金額.value = getTotal(record.明細.value);

    return event;
  });

  // 「単価」が変更されたら「小計」を再計算する
  kintone.events.on([
    'app.record.create.change.単価',
    'app.record.edit.change.単価'
  ], event => {
    const row = event.changes.row.value;

    console.log('change.単価');

    row.小計.value = getRowTotal(Number(row.単価.value), Number(row.数量.value));

    return event;
  });

  // 「数量」が変更されたら「小計」を再計算する
  kintone.events.on([
    'app.record.create.change.数量',
    'app.record.edit.change.数量'
  ], event => {
    const row = event.changes.row.value;

    console.log('change.数量');

    row.小計.value = getRowTotal(Number(row.単価.value), Number(row.数量.value));

    return event;
  });

  // 「小計」が変更されたら「合計金額」を再計算する
  kintone.events.on([
    'app.record.create.change.小計',
    'app.record.edit.change.小計'
  ], event => {
    const record = event.record;

    console.log('change.小計');

    record.合計金額.value = getTotal(record.明細.value);

    return event;
  });

  // 「合計金額」が変更されたら「総合計金額」を再計算する
  kintone.events.on([
    'app.record.create.change.合計金額',
    'app.record.edit.change.合計金額'
  ], event => {
    const record = event.record;

    console.log('change.合計金額');

    record.総合計金額.value = getAllTotal(Number(record.合計金額.value), Number(record.調整金額.value));

    return event;
  });

  // 「調整金額」が変更されたら「総合計金額」を再計算する
  kintone.events.on([
    'app.record.create.change.調整金額',
    'app.record.edit.change.調整金額'
  ], event => {
    const record = event.record;

    console.log('change.調整金額');

    record.総合計金額.value = getAllTotal(Number(record.合計金額.value), Number(record.調整金額.value));

    return event;
  });
})();
